{% load static %}
{% load inlinecss %}

{% inlinecss "css/email.css" %}
<div>
	<p>
		Dear {{ first_name }},<br><br>

		We can't wait to celebrate our marriage with you in just a few weeks! Please find below a confirmation of your response from the website as well as additional information about the events.
	</p>
</div>

{% if attending_rehearsal %}
<div>
	<h2> Rehearsal Dinner </h2>

	<p>We have the following people attending our Rehearsal Dinner on $DATE:</p>
	<ol>
	{% for person in attending_rehearsal %}
		<li>{{ person.name }}</li>
	{% endfor %}
	</ol>

	<p>We'll be gathering at <b>7:00PM</b> at:<br><br>
	<b>$RESTAURANT</b><br>
	<a href=$GOOGLR_MAPS_LINK>$ADDRESS<br>$CITY, $STATE $ZIP
	</a></p>

	<p>$PARKING INFO</p>

</div>
{% endif %}

{% if attending_wedding %}
<div>
	<h2> Wedding Ceremony and Reception </h2>

	<p>We have the following people attending our wedding on $DATE:</p>
	<ol>
	{% for person in attending_wedding %}
		<li style='font-family: "Arial"'>{{ person.name }}</li>
	{% endfor %}
	</ol>

	<p>The ceremony and reception are both being held at at:<br><br>
	<b>$VENUE</b><br>
	<a href="$GOOGLE_MAPS_LINK">
	$ADDRES<br>
	$CITY, $STATE $ZIP</a></p>

	<p>Please arrive <b>no later than $TIME</b> as the ceremony will begin promptly at $TIME</p>

	<p>$PARKING INFO</p>
</div>
{% endif %}

<div>
	<h2> General Information </h2>
	<p> Please feel free to reply directly to this email with any comments, questions or concerns about the wedding or events. If the information for your reservation is incorrect please let us know as soon as possible. This email was automatically generated, but the responses go directly to our inbox :).</p>

    <!-- TODO change the below url when we have one (or better yet find a way to make this generic) -->
	<p>On the day of the wedding, please reach out to $CONTACT PERSON if you need help finding the venue or have any other questions. You can view their contact information on the <a href="https://wedsite.io/contact">web site</a>.</p>

	<p>Sincerely,<br><br>$NEWLYWEDS</p>
</div>
{% endinlinecss %}
