{% extends "wedding/blocks/base.html" %}
{% load static %}

{% block title %}
Logout
{% endblock %}

{% block content %}
<div id="logout" class="container-fluid text-center page-container">
    <h1 class="page-header">Logout</h1>
    <p>
        Thanks for visiting the site!
    <br><br>
        <a href="{% url 'index' %}">Return to homepage</a>
    <br><br>
        <a href="{% url 'login' %}?next={% url 'index' %}">Log back in</a>
    </p>
</div>

{% endblock %}
